export type ConditionType = 'string' | 'number' | 'date' | 'boolean';
export type ConditionModelBase<T extends ConditionType> = {
    field: string;
    label: string;
    type: T;
    map?: {
        type: 'Map';
        key1Values?: string[] | {
            value: string;
            label: string;
        }[];
        key1Value?: string | null;
    } | {
        type: 'MultiMap';
        key1Value?: string | null;
        key1Values?: string[];
        key2Value?: string | null;
    };
};
export type StringConditionModel = ConditionModelBase<'string'> & {
    values?: string[] | {
        value: string;
        label: string;
    }[];
};
export type NumberConditionModel = ConditionModelBase<'number'> & {
    min?: number;
    max?: number;
};
export type DateConditionModel = ConditionModelBase<'date'>;
export type BooleanConditionModel = ConditionModelBase<'boolean'>;
export type ConditionModel = StringConditionModel | NumberConditionModel | DateConditionModel | BooleanConditionModel;
