import { JSONSchema7 } from 'json-schema';
import { GioMonacoEditorConfig } from '../type-component/code-editor-type.component';
/**
 * GioConfig is used to add some custom configuration to the JSONSchema7
 * ⚠️ Keep updated with the GioJsonSchema.json to have the same interface ⚠️
 */
export interface GioConfig extends GioUiTypeConfig {
    displayIf?: GioIfConfig;
    disableIf?: GioIfConfig;
    banner?: GioBannerConfig;
    monacoEditorConfig?: GioMonacoEditorConfig;
    enumLabelMap?: Record<string, string>;
    uiBorder?: 'none' | 'full';
}
type GioBannerConfig = {
    title: string;
    text: string;
} | {
    text: string;
};
/**
 * Used to override the default formly type. It's useful when we want to use a custom component.
 */
type GioUiTypeConfig = {
    uiType?: 'gio-headers-array' | string;
    uiTypeProps?: Record<string, unknown>;
};
export type GioIfConfig = {
    $eq: Record<string, string | number | boolean | Array<string | number | boolean>>;
};
/**
 * Override the JSONSchema7 interface to add gioConfig
 * Use this way because the JSONSchema7 interface is recursive
 * And export with new name `GioJsonSchema` to make it more clear
 */
declare module 'json-schema' {
    interface JSONSchema7 {
        gioConfig?: GioConfig;
        deprecated?: boolean;
    }
}
export type GioJsonSchema = JSONSchema7;
export {};
