import { FocusMonitor } from '@angular/cdk/a11y';
import { ChangeDetectorRef, DoCheck, ElementRef, OnDestroy } from '@angular/core';
import { ControlValueAccessor, NgControl } from '@angular/forms';
import { MatAutocompleteSelectedEvent } from '@angular/material/autocomplete';
import { MatFormFieldControl } from '@angular/material/form-field';
import { Observable, Subject } from 'rxjs';
import * as i0 from "@angular/core";
export type Tags = Array<string>;
export type AutocompleteOptions = (string | {
    value: string;
    label: string;
})[];
export type DisplayValueWithFn = (value: string) => Observable<string>;
export declare class GioFormTagsInputComponent implements MatFormFieldControl<Tags>, ControlValueAccessor, DoCheck, OnDestroy {
    readonly ngControl: NgControl;
    private readonly elRef;
    private readonly fm;
    private changeDetectorRef;
    private static nextId;
    _onChange: (_tags: Tags | null) => void;
    _onTouched: () => void;
    private touched;
    ariaLabel: string;
    addOnBlur: boolean;
    /**
     * Function called each time a tag is added, it can be used to hook inside the
     * addition process to, for instance, have custom validation in the components
     * using `gio-form-tags-input`.
     *
     * Parameters are:
     * - `tag`: The value of the tag to add
     * - `validationCb`: The callback function to call when validation is done. If
     * called with `true` it will add the tag, otherwise it will just ignore it
     */
    tagValidationHook: ((tag: string, validationCb: (shouldAddTag: boolean) => void) => void) | undefined;
    set autocompleteOptions(v: AutocompleteOptions | ((search: string) => Observable<AutocompleteOptions>) | undefined);
    _autocompleteOptions?: AutocompleteOptions | ((search: string) => Observable<AutocompleteOptions>);
    /**
     * Get the label of an option value.
     * To use with autocompleteOptions label & value mode.
     * Function called each time a tag needs to be displayed id defined.
     */
    set displayValueWith(displayValueWith: DisplayValueWithFn);
    /**
     * Set to true to force the chip to be part of the autocomplete options.
     */
    useAutocompleteOptionValueOnly: boolean;
    set tagInput(v: ElementRef<HTMLInputElement> | null);
    private _tagInput;
    autocompleteFilteredOptions$?: Observable<Record<string, string>[]>;
    _displayValueWith?: (value: string) => Observable<string>;
    private displayValueCache;
    loading: boolean;
    get value(): Tags | null;
    set value(_tags: Tags | null);
    private _value;
    stateChanges: Subject<void>;
    id: string;
    get placeholder(): string;
    set placeholder(plh: string);
    private _placeholder;
    focused: boolean;
    get empty(): boolean;
    get shouldLabelFloat(): boolean;
    get required(): boolean;
    set required(req: boolean);
    private _required;
    get disabled(): boolean;
    set disabled(dis: boolean);
    private _disabled;
    get errorState(): boolean;
    controlType?: string;
    autofilled?: boolean;
    userAriaDescribedBy?: string;
    constructor(ngControl: NgControl, elRef: ElementRef, fm: FocusMonitor, changeDetectorRef: ChangeDetectorRef);
    ngDoCheck(): void;
    ngOnDestroy(): void;
    setDisabledState(isDisabled: boolean): void;
    writeValue(value: string[]): void;
    registerOnChange(fn: (tags: Tags | null) => void): void;
    registerOnTouched(fn: () => void): void;
    describedBy: string;
    setDescribedByIds(ids: string[]): void;
    onContainerClick(_event: MouseEvent): void;
    addChipToFormControl(event: {
        value: string;
    }): void;
    removeChipToFormControl(tag: string): void;
    onAutocompleteSelect(event: MatAutocompleteSelectedEvent): void;
    onMatChipTokenEnd(): void;
    private initAutocomplete;
    static ɵfac: i0.ɵɵFactoryDeclaration<GioFormTagsInputComponent, [{ optional: true; self: true; }, null, null, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GioFormTagsInputComponent, "gio-form-tags-input", never, { "ariaLabel": { "alias": "aria-label"; "required": false; }; "addOnBlur": { "alias": "addOnBlur"; "required": false; }; "tagValidationHook": { "alias": "tagValidationHook"; "required": false; }; "autocompleteOptions": { "alias": "autocompleteOptions"; "required": false; }; "displayValueWith": { "alias": "displayValueWith"; "required": false; }; "useAutocompleteOptionValueOnly": { "alias": "useAutocompleteOptionValueOnly"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "required": { "alias": "required"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; }, {}, never, never, false, never>;
}
