import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { MatDialog } from '@angular/material/dialog';
import * as i0 from "@angular/core";
export type License = {
    tier: string;
    packs: Array<string>;
    features: Array<string>;
    expiresAt?: Date;
    scope?: string;
    isExpired?: boolean;
};
export interface LicenseConfiguration {
    resourceURL: string;
    featureInfoData: Record<string, FeatureInfo>;
    trialResourceURL: string;
    utmSource?: string;
    utmCampaign?: string;
}
export interface UTM {
    source: string;
    medium: string;
    campaign: string;
}
export type LicenseOptionsBase = {
    feature?: string;
    context?: string;
};
export type LicensePluginOptions = LicenseOptionsBase & {
    deployed: boolean;
};
export type LicenseOptions = LicenseOptionsBase | LicensePluginOptions;
export declare const isLicensePluginOptions: (licenseOptions: LicenseOptions) => licenseOptions is LicensePluginOptions;
export interface FeatureInfo {
    image?: string;
    description?: string;
    title?: string;
    trialButtonLabel?: string;
    hideDays?: boolean;
}
export declare class GioLicenseService {
    private readonly http;
    private readonly licenseConfiguration;
    private readonly matDialog;
    private readonly loadLicense$;
    constructor(http: HttpClient, licenseConfiguration: LicenseConfiguration, matDialog: MatDialog);
    getLicense$(): Observable<License>;
    isMissingFeature$(feature: string | undefined): Observable<boolean>;
    hasAllFeatures$(licenseOptions: LicenseOptions[] | undefined): Observable<boolean>;
    getFeatureInfo(licenseOptions: LicenseOptions): FeatureInfo;
    getTrialURL(licenseOptions: LicenseOptions): string;
    isOEM$(): Observable<boolean>;
    openDialog(licenseOptions: LicenseOptions, event?: Event): import("rxjs").Subscription;
    getExpiresAt$(): Observable<Date | undefined>;
    isExpired$(): Observable<boolean>;
    static ɵfac: i0.ɵɵFactoryDeclaration<GioLicenseService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<GioLicenseService>;
}
